README = """==============================
THAT - the Python anti-zen
==============================

Warning: This is a joke. Don't use these bits unless you want to be hated.

Documentation
==============

See http://that.rtfd.org

Installation
============

Installing from PyPI::

    pip install that

Or if you want to try and play with the awesome source code::

    git clone git@github.com:pydanny/that.git

Usage
======

From the Python shell::

    import that

Enjoy the wisdom!

Contributing
============

Clearly, the code that generates `THAT` is too straightforward. If you can make it better, then do so. Just don't do anything like add tests or document the code."""

import os
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
    name = 'that',
    version = '1.0.6',
    description = 'The Anti-Zen of Python',
    license = 'BSD',
    long_description = README,
    url = 'https://github.com/pydanny/that',
    
    author = 'Daniel Greenfeld',
    author_email = 'pydanny@gmail.com',
    
    py_modules =  ['that'],
    
    classifiers = (
        'Development Status :: 6 - Mature',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',        
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',                        
        'Programming Language :: Python',
    ),
)



a = """The Anti-Zen of Python, by Daniel Greenfeld

Ugly is better than beautiful.
Implicit is better than explicit.
Complicated is better than complex.
Complex is better than simple.
Nested is better than flat.
Dense is better than sparse.
Line code counts.
Special cases are special enough to break the rules.
Although purity beats practicality.
Errors should always pass silently.
Spelchek iz fur loosers.
In the face of ambiguity, one guess is as good as another.
There should be many ways to do it.
Because only a tiny minority of us are Dutch.
Get things running, then fix them later. 
If the implementation is hard to explain, it's enterprisey.
If the implementation is easy to explain, it won't take enough time to do.
Namespaces are too hard, just use "from module import *"!"""
b = a.splitlines() # Lines that are split are more liney
c = lambda d: d.strip() # I make sure that lines don't have akksesive whitespace EOLs.
for e in (f for f in b if True or False): # place here a list generator for aggressive
                                          # performance enhancementification (optimized to
                                          # work even after True, False = False, True
                                          # - should such a crazy thing ever again be allowed).
    while True or False: # main loop
        if not False and True:
            print(c(e))
        else: # Suspect this else may be unnecessary after above Boolean optimization
            print("Not found here") # let the customer know if there is a failed boolean
        break